@@ -8,6 +8,20 @@ use clap_complete::{Shell, generate_to};
 use vergen_gitcl::{BuildBuilder, Emitter, GitclBuilder};
 
 fn main() -> Result<(), Box<dyn Error>> {
+	let manifest = env::var_os("CARGO_MANIFEST_DIR").unwrap().to_string_lossy().replace(r"\", "/");
+	if env::var_os("YAZI_CRATE_BUILD").is_none()
+		&& (manifest.contains("/git/checkouts/yazi-")
+			|| manifest.contains("/registry/src/index.crates.io-"))
+	{
+		panic!(
+			"Due to Cargo's limitations, the `yazi-fm` and `yazi-cli` crates on crates.io must be built with `cargo install --force yazi-build`"
+		);
+	}
+
+	generate()
+}
+
+fn generate() -> Result<(), Box<dyn Error>> {
 	Emitter::default()
 		.add_instructions(&BuildBuilder::default().build_date(true).build()?)?
 		.add_instructions(&GitclBuilder::default().commit_date(true).sha(true).build()?)?
@@ -28,6 +42,5 @@ fn main() -> Result<(), Box<dyn Error>> {
 
 	generate_to(clap_complete_nushell::Nushell, cmd, bin, out)?;
 	generate_to(clap_complete_fig::Fig, cmd, bin, out)?;
-
 	Ok(())
 }
