@@ -1,8 +1,8 @@
-use std::borrow::Cow;
+use std::{borrow::Cow, ffi::OsString};
 
 use anyhow::{Result, bail};
-use clap::{Parser, Subcommand, command};
-use yazi_shared::{Id, event::Cmd};
+use clap::{Parser, Subcommand};
+use yazi_shared::{Either, Id};
 
 #[derive(Parser)]
 #[command(name = "Ya", about, long_about = None)]
@@ -24,9 +24,6 @@ pub(super) enum Command {
 	/// Manage packages.
 	#[command(subcommand)]
 	Pkg(CommandPkg),
-	#[command(hide = true)]
-	/// Manage packages.
-	Pack(CommandPack), // TODO: remove
 	/// Publish a message to the current instance.
 	Pub(CommandPub),
 	/// Publish a message to the specified instance.
@@ -37,22 +34,22 @@ pub(super) enum Command {
 
 #[derive(clap::Args)]
 pub(super) struct CommandEmit {
-	/// The name of the command.
+	/// Name of the command.
 	pub(super) name: String,
-	/// The arguments of the command.
+	/// Arguments of the command.
 	#[arg(allow_hyphen_values = true, trailing_var_arg = true)]
-	pub(super) args: Vec<String>,
+	pub(super) args: Vec<OsString>,
 }
 
 #[derive(clap::Args)]
 pub(super) struct CommandEmitTo {
-	/// The receiver ID.
+	/// Receiver ID.
 	pub(super) receiver: Id,
-	/// The name of the command.
+	/// Name of the command.
 	pub(super) name:     String,
-	/// The arguments of the command.
+	/// Arguments of the command.
 	#[arg(allow_hyphen_values = true, trailing_var_arg = true)]
-	pub(super) args:     Vec<String>,
+	pub(super) args:     Vec<OsString>,
 }
 
 #[derive(Subcommand)]
@@ -60,14 +57,14 @@ pub(super) enum CommandPkg {
 	/// Add packages.
 	#[command(arg_required_else_help = true)]
 	Add {
-		/// The packages to add.
+		/// Packages to add.
 		#[arg(index = 1, num_args = 1..)]
 		ids: Vec<String>,
 	},
 	/// Delete packages.
 	#[command(arg_required_else_help = true)]
 	Delete {
-		/// The packages to delete.
+		/// Packages to delete.
 		#[arg(index = 1, num_args = 1..)]
 		ids: Vec<String>,
 	},
@@ -76,32 +73,16 @@ pub(super) enum CommandPkg {
 	/// List all packages.
 	List,
 	/// Upgrade all packages.
-	Upgrade,
-}
-
-#[derive(clap::Args)]
-#[command(arg_required_else_help = true)]
-pub(super) struct CommandPack {
-	/// Add packages.
-	#[arg(short = 'a', long, num_args = 1..)]
-	pub(super) add:     Option<Vec<String>>,
-	/// Delete packages.
-	#[arg(short = 'd', long, num_args = 1..)]
-	pub(super) delete:  Option<Vec<String>>,
-	/// Install all packages.
-	#[arg(short = 'i', long)]
-	pub(super) install: bool,
-	/// List all packages.
-	#[arg(short = 'l', long)]
-	pub(super) list:    bool,
-	/// Upgrade all packages.
-	#[arg(short = 'u', long)]
-	pub(super) upgrade: bool,
+	Upgrade {
+		/// Packages to upgrade, upgrade all if unspecified.
+		#[arg(index = 1, num_args = 0..)]
+		ids: Vec<String>,
+	},
 }
 
 #[derive(clap::Args)]
 pub(super) struct CommandPub {
-	/// The kind of message.
+	/// Kind of message.
 	#[arg(index = 1)]
 	pub(super) kind: String,
 	/// Send the message with a string body.
@@ -128,10 +109,10 @@ impl CommandPub {
 
 #[derive(clap::Args)]
 pub(super) struct CommandPubTo {
-	/// The receiver ID.
+	/// Receiver ID.
 	#[arg(index = 1)]
 	pub(super) receiver: Id,
-	/// The kind of message.
+	/// Kind of message.
 	#[arg(index = 2)]
 	pub(super) kind:     String,
 	/// Send the message with a string body.
@@ -147,7 +128,7 @@ pub(super) struct CommandPubTo {
 
 #[derive(clap::Args)]
 pub(super) struct CommandSub {
-	/// The kind of messages to subscribe to, separated by commas if multiple.
+	/// Kind of messages to subscribe to, separated by commas if multiple.
 	#[arg(index = 1)]
 	pub(super) kinds: String,
 }
@@ -158,10 +139,11 @@ macro_rules! impl_emit_body {
 		impl $name {
 			#[allow(dead_code)]
 			pub(super) fn body(self) -> Result<String> {
-				Ok(serde_json::to_string(&(
-					self.name,
-					Cmd::parse_args(self.args.into_iter(), None, false)?,
-				))?)
+				let cmd: Vec<_> = [Either::Left(self.name)]
+					.into_iter()
+					.chain(self.args.into_iter().map(|s| Either::Right(s.into_encoded_bytes())))
+					.collect();
+				Ok(serde_json::to_string(&cmd)?)
 			}
 		}
 	};
@@ -171,7 +153,7 @@ macro_rules! impl_pub_body {
 	($name:ident) => {
 		impl $name {
 			#[allow(dead_code)]
-			pub(super) fn body(&self) -> Result<Cow<str>> {
+			pub(super) fn body(&self) -> Result<Cow<'_, str>> {
 				Ok(if let Some(json) = &self.json {
 					json.into()
 				} else if let Some(str) = &self.str {
