@@ -1,7 +1,7 @@
 use anyhow::Result;
-use yazi_fs::must_exists;
 
 use super::{Dependency, Git};
+use crate::shared::must_exists;
 
 impl Dependency {
 	pub(super) async fn install(&mut self) -> Result<()> {
@@ -19,7 +19,10 @@ impl Dependency {
 		}
 
 		self.deploy().await?;
-		self.rev = Git::revision(&path).await?;
+		if self.rev.is_empty() {
+			self.rev = Git::revision(&path).await?;
+		}
+
 		Ok(())
 	}
 }
