@@ -2,9 +2,8 @@ use std::{path::PathBuf, str::FromStr};
 
 use anyhow::{Context, Result, bail};
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
-use tokio::fs;
-use yazi_fs::Xdg;
-use yazi_macro::outln;
+use yazi_fs::{Xdg, provider::{Provider, local::Local}};
+use yazi_macro::{ok_or_not_found, outln};
 
 use super::Dependency;
 
@@ -16,11 +15,8 @@ pub(crate) struct Package {
 
 impl Package {
 	pub(crate) async fn load() -> Result<Self> {
-		Ok(match fs::read_to_string(Self::toml()).await {
-			Ok(s) => toml::from_str(&s)?,
-			Err(e) if e.kind() == std::io::ErrorKind::NotFound => Self::default(),
-			Err(e) => Err(e)?,
-		})
+		let s = ok_or_not_found!(Local::regular(&Self::toml()).read_to_string().await);
+		Ok(toml::from_str(&s)?)
 	}
 
 	pub(crate) async fn add_many(&mut self, uses: &[String]) -> Result<()> {
@@ -41,18 +37,40 @@ impl Package {
 		Ok(())
 	}
 
-	pub(crate) async fn install(&mut self, upgrade: bool) -> Result<()> {
+	pub(crate) async fn install(&mut self) -> Result<()> {
+		macro_rules! go {
+			($dep:expr) => {
+				let r = $dep.install().await;
+				self.save().await?;
+				r?;
+			};
+		}
+
 		for i in 0..self.plugins.len() {
-			let r =
-				if upgrade { self.plugins[i].upgrade().await } else { self.plugins[i].install().await };
-			self.save().await?;
-			r?;
+			go!(self.plugins[i]);
 		}
 		for i in 0..self.flavors.len() {
-			let r =
-				if upgrade { self.flavors[i].upgrade().await } else { self.flavors[i].install().await };
-			self.save().await?;
-			r?;
+			go!(self.flavors[i]);
+		}
+		Ok(())
+	}
+
+	pub(crate) async fn upgrade_many(&mut self, uses: &[String]) -> Result<()> {
+		macro_rules! go {
+			($dep:expr) => {
+				if uses.is_empty() || uses.contains(&$dep.r#use) {
+					let r = $dep.upgrade().await;
+					self.save().await?;
+					r?;
+				}
+			};
+		}
+
+		for i in 0..self.plugins.len() {
+			go!(self.plugins[i]);
+		}
+		for i in 0..self.flavors.len() {
+			go!(self.flavors[i]);
 		}
 		Ok(())
 	}
@@ -114,13 +132,11 @@ impl Package {
 
 	async fn save(&self) -> Result<()> {
 		let s = toml::to_string_pretty(self)?;
-		fs::write(Self::toml(), s).await.context("Failed to write package.toml")
+		Local::regular(&Self::toml()).write(s).await.context("Failed to write package.toml")
 	}
 
-	#[inline]
 	fn toml() -> PathBuf { Xdg::config_dir().join("package.toml") }
 
-	#[inline]
 	fn identical(&self, other: &Dependency) -> Option<&Dependency> {
 		self.plugins.iter().chain(&self.flavors).find(|d| d.identical(other))
 	}
