@@ -3,7 +3,7 @@ use std::{borrow::Cow, hash::{Hash, Hasher}, sync::OnceLock};
 use anyhow::Result;
 use regex::Regex;
 use serde::Deserialize;
-use yazi_shared::{Layer, event::Cmd};
+use yazi_shared::{Layer, Source, event::Cmd};
 
 use super::Key;
 
@@ -38,11 +38,11 @@ impl Chord {
 			.into_owned()
 	}
 
-	pub fn desc(&self) -> Option<Cow<str>> {
+	pub fn desc(&self) -> Option<Cow<'_, str>> {
 		self.desc.as_ref().map(|s| RE.get_or_init(|| Regex::new(r"\s+").unwrap()).replace_all(s, " "))
 	}
 
-	pub fn desc_or_run(&self) -> Cow<str> { self.desc().unwrap_or_else(|| self.run().into()) }
+	pub fn desc_or_run(&self) -> Cow<'_, str> { self.desc().unwrap_or_else(|| self.run().into()) }
 
 	pub fn contains(&self, s: &str) -> bool {
 		let s = s.to_lowercase();
@@ -60,6 +60,7 @@ impl Chord {
 impl Chord {
 	pub(super) fn reshape(mut self, layer: Layer) -> Result<Self> {
 		for cmd in &mut self.run {
+			cmd.source = Source::Key;
 			if cmd.layer == Default::default() {
 				cmd.layer = layer;
 			}
