@@ -1,6 +1,7 @@
-use anyhow::Result;
+use anyhow::{Context, Result};
 use serde::Deserialize;
 use yazi_codegen::DeserializeOver1;
+use yazi_fs::{Xdg, ok_or_not_found};
 use yazi_shared::Layer;
 
 use super::{Chord, KeymapRules};
@@ -18,7 +19,6 @@ pub struct Keymap {
 }
 
 impl Keymap {
-	#[inline]
 	pub fn get(&self, layer: Layer) -> &[Chord] {
 		match layer {
 			Layer::App => &[],
@@ -36,6 +36,12 @@ impl Keymap {
 }
 
 impl Keymap {
+	pub(crate) fn read() -> Result<String> {
+		let p = Xdg::config_dir().join("keymap.toml");
+		ok_or_not_found(std::fs::read_to_string(&p))
+			.with_context(|| format!("Failed to read keymap {p:?}"))
+	}
+
 	pub(crate) fn reshape(self) -> Result<Self> {
 		Ok(Self {
 			mgr:     self.mgr.reshape(Layer::Mgr)?,
