@@ -1,19 +1,16 @@
-use crate::{Yazi, keymap::Keymap, theme::Theme};
+use crate::{Yazi, keymap::Keymap, theme::Theme, vfs::Vfs};
 
 pub(crate) struct Preset;
 
 impl Preset {
-	#[inline]
 	pub(super) fn yazi() -> Result<Yazi, toml::de::Error> {
 		toml::from_str(&yazi_macro::config_preset!("yazi"))
 	}
 
-	#[inline]
 	pub(super) fn keymap() -> Result<Keymap, toml::de::Error> {
 		toml::from_str(&yazi_macro::config_preset!("keymap"))
 	}
 
-	#[inline]
 	pub(super) fn theme(light: bool) -> Result<Theme, toml::de::Error> {
 		toml::from_str(&if light {
 			yazi_macro::theme_preset!("light")
@@ -22,6 +19,10 @@ impl Preset {
 		})
 	}
 
+	pub(super) fn vfs() -> Result<Vfs, toml::de::Error> {
+		toml::from_str(&yazi_macro::config_preset!("vfs"))
+	}
+
 	#[inline]
 	pub(crate) fn mix<E, A, B, C>(a: A, b: B, c: C) -> impl Iterator<Item = E>
 	where
