@@ -3,10 +3,9 @@ use std::ops::Deref;
 use serde::Deserialize;
 use yazi_codegen::DeserializeOver2;
 use yazi_fs::File;
-use yazi_shared::theme::Style;
 
 use super::Is;
-use crate::Pattern;
+use crate::{Pattern, Style};
 
 #[derive(Deserialize, DeserializeOver2)]
 pub struct Filetype {
@@ -23,7 +22,7 @@ impl Deref for Filetype {
 pub struct FiletypeRule {
 	#[serde(default)]
 	is:        Is,
-	name:      Option<Pattern>,
+	url:       Option<Pattern>,
 	mime:      Option<Pattern>,
 	#[serde(flatten)]
 	pub style: Style,
@@ -36,6 +35,6 @@ impl FiletypeRule {
 		}
 
 		self.mime.as_ref().is_some_and(|p| p.match_mime(mime))
-			|| self.name.as_ref().is_some_and(|n| n.match_path(&file.url, file.is_dir()))
+			|| self.url.as_ref().is_some_and(|n| n.match_url(&file.url, file.is_dir()))
 	}
 }
