@@ -1,12 +1,14 @@
-use std::{collections::HashMap, ops::Deref};
+use std::ops::Deref;
 
 use anyhow::Result;
+use hashbrown::HashMap;
+use ratatui::style::Color;
 use serde::{Deserialize, Deserializer};
 use yazi_codegen::DeserializeOver2;
 use yazi_fs::File;
-use yazi_shared::{Condition, theme::{Color, Icon as I, Style}};
+use yazi_shared::{Condition, url::UrlLike};
 
-use crate::Pattern;
+use crate::{Icon as I, Pattern, Style};
 
 #[derive(Default, Deserialize, DeserializeOver2)]
 pub struct Icon {
@@ -68,14 +70,12 @@ impl Icon {
 		self.conds.iter().find(|(c, _)| c.eval(f) == Some(true)).map(|(_, i)| i)
 	}
 
-	#[inline]
 	fn match_by_glob(&self, file: &File) -> Option<&I> {
-		self.globs.iter().find(|(p, _)| p.match_path(&file.url, file.is_dir())).map(|(_, i)| i)
+		self.globs.iter().find(|(p, _)| p.match_url(&file.url, file.is_dir())).map(|(_, i)| i)
 	}
 
-	#[inline]
 	fn match_by_name(&self, file: &File) -> Option<&I> {
-		let name = file.name().to_str()?;
+		let name = file.name()?.to_str().ok()?;
 		if file.is_dir() {
 			self.dirs.get(name).or_else(|| self.dirs.get(&name.to_ascii_lowercase()))
 		} else {
@@ -87,9 +87,8 @@ impl Icon {
 		}
 	}
 
-	#[inline]
 	fn match_by_ext(&self, file: &File) -> Option<&I> {
-		let ext = file.url.extension()?.to_str()?;
+		let ext = file.url.ext()?.to_str().ok()?;
 		self.exts.get(ext).or_else(|| self.exts.get(&ext.to_ascii_lowercase()))
 	}
 }
@@ -133,7 +132,7 @@ impl<'de> Deserialize<'de> for PatIcons {
 	{
 		#[derive(Deserialize)]
 		struct Shadow {
-			name: Pattern,
+			url:  Pattern,
 			text: String,
 			fg:   Option<Color>,
 		}
@@ -141,7 +140,7 @@ impl<'de> Deserialize<'de> for PatIcons {
 		Ok(Self(
 			<Vec<Shadow>>::deserialize(deserializer)?
 				.into_iter()
-				.map(|s| (s.name, I { text: s.text, style: Style { fg: s.fg, ..Default::default() } }))
+				.map(|s| (s.url, I { text: s.text, style: Style { fg: s.fg, ..Default::default() } }))
 				.collect(),
 		))
 	}
