@@ -1,20 +1,20 @@
-use std::time::Instant;
+use std::time::{Duration, Instant};
 
-use yazi_macro::emit;
-use yazi_shared::event::Cmd;
+use yazi_parser::app::NotifyOpt;
+use yazi_proxy::AppProxy;
 
 use crate::notify::{Message, Notify};
 
 impl Notify {
-	pub fn push(&mut self, msg: impl Into<Message>) {
-		let mut msg = msg.into() as Message;
-
+	pub fn push(&mut self, opt: NotifyOpt) {
 		let instant = Instant::now();
+
+		let mut msg = Message::from(opt);
 		msg.timeout += instant - self.messages.first().map_or(instant, |m| m.instant);
 
 		if self.messages.iter().all(|m| m != &msg) {
 			self.messages.push(msg);
-			emit!(Call(Cmd::args("app:update_notify", &[0])));
+			AppProxy::update_notify(Duration::ZERO);
 		}
 	}
 }
