@@ -1,40 +1,14 @@
 use std::time::Duration;
 
 use ratatui::layout::Rect;
-use yazi_macro::emit;
-use yazi_shared::event::{Cmd, CmdCow, Data};
+use yazi_parser::notify::TickOpt;
+use yazi_proxy::AppProxy;
 
 use crate::notify::Notify;
 
-pub struct Opt {
-	interval: Duration,
-}
-
-impl TryFrom<CmdCow> for Opt {
-	type Error = ();
-
-	fn try_from(c: CmdCow) -> Result<Self, Self::Error> {
-		let interval = c.first().and_then(Data::as_f64).ok_or(())?;
-		if interval < 0.0 {
-			return Err(());
-		}
-
-		Ok(Self { interval: Duration::from_secs_f64(interval) })
-	}
-}
-
-impl TryFrom<Cmd> for Opt {
-	type Error = ();
-
-	fn try_from(c: Cmd) -> Result<Self, Self::Error> { Self::try_from(CmdCow::from(c)) }
-}
-
 impl Notify {
-	pub fn tick(&mut self, opt: impl TryInto<Opt>, area: Rect) {
+	pub fn tick(&mut self, opt: TickOpt, area: Rect) {
 		self.tick_handle.take().map(|h| h.abort());
-		let Ok(opt) = opt.try_into() else {
-			return;
-		};
 
 		let limit = self.limit(area);
 		if limit == 0 {
@@ -69,7 +43,7 @@ impl Notify {
 
 		self.tick_handle = Some(tokio::spawn(async move {
 			tokio::time::sleep(interval).await;
-			emit!(Call(Cmd::args("app:update_notify", &[interval.as_secs_f64()])));
+			AppProxy::update_notify(interval);
 		}));
 	}
 }
