@@ -19,22 +19,22 @@ impl Default for Preference {
 	fn default() -> Self {
 		Self {
 			// Sorting
-			sort_by:        YAZI.mgr.sort_by,
-			sort_sensitive: YAZI.mgr.sort_sensitive,
-			sort_reverse:   YAZI.mgr.sort_reverse,
-			sort_dir_first: YAZI.mgr.sort_dir_first,
-			sort_translit:  YAZI.mgr.sort_translit,
+			sort_by:        YAZI.mgr.sort_by.get(),
+			sort_sensitive: YAZI.mgr.sort_sensitive.get(),
+			sort_reverse:   YAZI.mgr.sort_reverse.get(),
+			sort_dir_first: YAZI.mgr.sort_dir_first.get(),
+			sort_translit:  YAZI.mgr.sort_translit.get(),
 
 			// Display
-			linemode:    YAZI.mgr.linemode.to_owned(),
-			show_hidden: YAZI.mgr.show_hidden,
+			linemode:    YAZI.mgr.linemode.clone(),
+			show_hidden: YAZI.mgr.show_hidden.get(),
 		}
 	}
 }
 
 impl From<&Preference> for FilesSorter {
 	fn from(value: &Preference) -> Self {
-		FilesSorter {
+		Self {
 			by:        value.sort_by,
 			sensitive: value.sort_sensitive,
 			reverse:   value.sort_reverse,
