@@ -1,13 +1,10 @@
-use std::iter;
-
 use anyhow::Result;
 use ratatui::layout::Rect;
 use tokio::task::JoinHandle;
 use yazi_adapter::Dimension;
 use yazi_config::{LAYOUT, popup::{Origin, Position}};
-use yazi_fs::{File, FolderStage};
-use yazi_macro::render;
-use yazi_shared::{Id, Ids, url::Url};
+use yazi_fs::File;
+use yazi_shared::{Id, Ids, url::UrlBuf};
 
 use super::{Backstack, Finder, Folder, History, Mode, Preference, Preview};
 use crate::{spot::Spot, tab::Selected};
@@ -19,7 +16,7 @@ pub struct Tab {
 	pub current: Folder,
 	pub parent:  Option<Folder>,
 
-	pub backstack: Backstack<Url>,
+	pub backstack: Backstack,
 	pub history:   History,
 	pub selected:  Selected,
 
@@ -62,11 +59,14 @@ impl Tab {
 impl Tab {
 	// --- Current
 	#[inline]
-	pub fn cwd(&self) -> &Url { &self.current.url }
+	pub fn cwd(&self) -> &UrlBuf { &self.current.url }
 
 	#[inline]
 	pub fn hovered(&self) -> Option<&File> { self.current.hovered() }
 
+	#[inline]
+	pub fn hovered_mut(&mut self) -> Option<&mut File> { self.current.hovered_mut() }
+
 	pub fn hovered_rect(&self) -> Option<Rect> {
 		let y = self.current.files.position(self.hovered()?.urn())? - self.current.offset;
 
@@ -85,20 +85,22 @@ impl Tab {
 		}
 	}
 
-	pub fn selected_or_hovered(&self) -> Box<dyn Iterator<Item = &Url> + '_> {
+	pub fn selected_or_hovered(&self) -> Box<dyn Iterator<Item = &UrlBuf> + '_> {
 		if self.selected.is_empty() {
-			Box::new(self.hovered().map(|h| vec![&h.url]).unwrap_or_default().into_iter())
+			Box::new(self.hovered().map(|h| &h.url).into_iter())
 		} else {
-			Box::new(self.selected.keys())
+			Box::new(self.selected.values())
 		}
 	}
 
-	pub fn hovered_and_selected(&self) -> Box<dyn Iterator<Item = &Url> + '_> {
-		let Some(h) = self.hovered() else { return Box::new(iter::empty()) };
+	pub fn hovered_and_selected(&self) -> Box<dyn Iterator<Item = &UrlBuf> + '_> {
+		let Some(h) = self.hovered() else {
+			return Box::new([UrlBuf::new()].into_iter().chain(self.selected.values()));
+		};
 		if self.selected.is_empty() {
 			Box::new([&h.url, &h.url].into_iter())
 		} else {
-			Box::new([&h.url].into_iter().chain(self.selected.keys()))
+			Box::new([&h.url].into_iter().chain(self.selected.values()))
 		}
 	}
 
@@ -108,31 +110,8 @@ impl Tab {
 		self.hovered().filter(|&h| h.is_dir()).and_then(|h| self.history.get(&h.url))
 	}
 
-	pub fn apply_files_attrs(&mut self) {
-		let apply = |f: &mut Folder| {
-			if f.stage == FolderStage::Loading {
-				return render!();
-			}
-
-			f.files.set_show_hidden(self.pref.show_hidden);
-			f.files.set_sorter(<_>::from(&self.pref));
-
-			render!(f.files.catchup_revision());
-			render!(f.repos(f.trace.clone()));
-		};
-
-		apply(&mut self.current);
-
-		if let Some(parent) = &mut self.parent {
-			apply(parent);
-			parent.hover(self.current.url.urn()); // The parent should always track the CWD
-		}
-
-		self
-			.current
-			.hovered()
-			.filter(|h| h.is_dir())
-			.and_then(|h| self.history.get_mut(&h.url))
-			.map(apply);
+	#[inline]
+	pub fn hovered_folder_mut(&mut self) -> Option<&mut Folder> {
+		self.current.hovered_mut().filter(|h| h.is_dir()).and_then(|h| self.history.get_mut(&h.url))
 	}
 }
