@@ -1,6 +1,4 @@
-yazi_macro::mod_pub!(commands);
-
-yazi_macro::mod_flat!(file plugin preload process progress tasks);
+yazi_macro::mod_flat!(file plugin prework process tasks);
 
 pub const TASKS_BORDER: u16 = 2;
 pub const TASKS_PADDING: u16 = 2;
