@@ -1,13 +1,15 @@
-use std::{collections::{HashMap, HashSet}, mem, str::FromStr};
+use std::{iter, mem, str::FromStr};
 
 use anyhow::{Context, Result, bail};
+use hashbrown::{HashMap, HashSet};
 use parking_lot::RwLock;
 use serde::{Deserialize, Serialize};
 use tokio::{io::AsyncWriteExt, select, sync::mpsc, task::JoinHandle, time};
 use tracing::error;
+use yazi_macro::try_format;
 use yazi_shared::{Id, RoCell};
 
-use crate::{ClientReader, ClientWriter, Payload, Pubsub, Server, Stream, body::{Body, BodyBye, BodyHi}};
+use crate::{ClientReader, ClientWriter, Payload, Pubsub, Server, Stream, ember::{Ember, EmberBye, EmberHi}};
 
 pub static ID: RoCell<Id> = RoCell::new();
 pub(super) static PEERS: RoCell<RwLock<HashMap<Id, Peer>>> = RoCell::new();
@@ -22,7 +24,7 @@ pub struct Client {
 	pub(super) abilities: HashSet<String>,
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Deserialize, Serialize)]
 pub struct Peer {
 	pub(super) abilities: HashSet<String>,
 }
@@ -55,7 +57,7 @@ impl Client {
 							continue;
 						} else if line.starts_with("hey,") {
 							Self::handle_hey(&line);
-						} else if let Err(e) = Payload::from_str(&line).map(|p| p.emit()) {
+						} else if let Err(e) = Payload::from_str(&line).and_then(|p| p.emit()) {
 							error!("Could not parse payload:\n{line}\n\nError:\n{e}");
 						}
 					}
@@ -66,13 +68,13 @@ impl Client {
 
 	/// Connect to an existing server to send a single message.
 	pub async fn shot(kind: &str, receiver: Id, body: &str) -> Result<()> {
-		Body::validate(kind)?;
+		Ember::validate(kind)?;
 
-		let payload = format!(
+		let payload = try_format!(
 			"{}\n{kind},{receiver},{ID},{body}\n{}\n",
-			Payload::new(BodyHi::borrowed(Default::default())),
-			Payload::new(BodyBye::owned())
-		);
+			Payload::new(EmberHi::borrowed(iter::empty())),
+			Payload::new(EmberBye::owned())
+		)?;
 
 		let (mut lines, mut writer) = Stream::connect().await?;
 		writer.write_all(payload.as_bytes()).await?;
@@ -83,7 +85,7 @@ impl Client {
 		while let Ok(Some(line)) = lines.next_line().await {
 			match line.split(',').next() {
 				Some("hey") => {
-					if let Ok(Body::Hey(hey)) = Payload::from_str(&line).map(|p| p.body) {
+					if let Ok(Ember::Hey(hey)) = Payload::from_str(&line).map(|p| p.body) {
 						(peers, version) = (hey.peers, Some(hey.version));
 					}
 				}
@@ -92,10 +94,10 @@ impl Client {
 			}
 		}
 
-		if version.as_deref() != Some(BodyHi::version()) {
+		if version.as_deref() != Some(EmberHi::version()) {
 			bail!(
 				"Incompatible version (Ya {}, Yazi {}). Restart all `ya` and `yazi` processes if you upgrade either one.",
-				BodyHi::version(),
+				EmberHi::version(),
 				version.as_deref().unwrap_or("Unknown")
 			);
 		}
@@ -128,8 +130,8 @@ impl Client {
 	pub async fn draw(kinds: HashSet<&str>) -> Result<()> {
 		async fn make(kinds: &HashSet<&str>) -> Result<ClientReader> {
 			let (lines, mut writer) = Stream::connect().await?;
-			let hi = Payload::new(BodyHi::borrowed(kinds.clone()));
-			writer.write_all(format!("{hi}\n").as_bytes()).await?;
+			let hi = Payload::new(EmberHi::borrowed(kinds.iter().copied()));
+			writer.write_all(try_format!("{hi}\n")?.as_bytes()).await?;
 			writer.flush().await?;
 			Ok(lines)
 		}
@@ -154,19 +156,17 @@ impl Client {
 		}
 	}
 
-	#[inline]
-	pub(super) fn push<'a>(payload: impl Into<Payload<'a>>) {
-		QUEUE_TX.send(format!("{}\n", payload.into())).ok();
+	pub(super) fn push<'a>(payload: impl Into<Payload<'a>>) -> Result<()> {
+		Ok(QUEUE_TX.send(try_format!("{}\n", payload.into())?)?)
 	}
 
-	#[inline]
 	pub(super) fn able(&self, ability: &str) -> bool { self.abilities.contains(ability) }
 
 	async fn connect(server: &mut Option<JoinHandle<()>>) -> (ClientReader, ClientWriter) {
 		let mut first = true;
 		loop {
 			if let Ok(conn) = Stream::connect().await {
-				Pubsub::pub_from_hi();
+				Pubsub::pub_inner_hi();
 				return conn;
 			}
 
@@ -191,7 +191,7 @@ impl Client {
 	}
 
 	fn handle_hey(s: &str) {
-		if let Ok(Body::Hey(mut hey)) = Payload::from_str(s).map(|p| p.body) {
+		if let Ok(Ember::Hey(mut hey)) = Payload::from_str(s).map(|p| p.body) {
 			hey.peers.retain(|&id, _| id != *ID);
 			*PEERS.write() = hey.peers;
 		}
@@ -199,9 +199,7 @@ impl Client {
 }
 
 impl Peer {
-	#[inline]
 	pub(super) fn new(abilities: &HashSet<String>) -> Self { Self { abilities: abilities.clone() } }
 
-	#[inline]
 	pub(super) fn able(&self, ability: &str) -> bool { self.abilities.contains(ability) }
 }
