@@ -1,9 +1,11 @@
-use std::{collections::HashMap, mem, ops::Deref, sync::atomic::{AtomicU64, Ordering}, time::UNIX_EPOCH};
+use std::{mem, ops::Deref, sync::atomic::{AtomicU64, Ordering}};
 
 use anyhow::Result;
+use hashbrown::HashMap;
 use parking_lot::RwLock;
-use tokio::{fs::{self, File, OpenOptions}, io::{AsyncBufReadExt, AsyncWriteExt, BufReader, BufWriter}};
+use tokio::io::{AsyncBufReadExt, AsyncWriteExt, BufReader, BufWriter};
 use yazi_boot::BOOT;
+use yazi_fs::provider::{FileBuilder, Provider, local::{Gate, Local}};
 use yazi_shared::{RoCell, timestamp_us};
 
 use crate::CLIENTS;
@@ -56,9 +58,9 @@ impl State {
 			return Ok(());
 		}
 
-		fs::create_dir_all(&BOOT.state_dir).await?;
+		Local::regular(&BOOT.state_dir).create_dir_all().await?;
 		let mut buf = BufWriter::new(
-			OpenOptions::new()
+			Gate::default()
 				.write(true)
 				.create(true)
 				.truncate(true)
@@ -77,7 +79,7 @@ impl State {
 	}
 
 	async fn load(&self) -> Result<()> {
-		let mut file = BufReader::new(File::open(BOOT.state_dir.join(".dds")).await?);
+		let mut file = BufReader::new(Local::regular(&BOOT.state_dir.join(".dds")).open().await?);
 		let mut buf = String::new();
 
 		let mut inner = HashMap::new();
@@ -101,8 +103,8 @@ impl State {
 	}
 
 	async fn skip(&self) -> Result<bool> {
-		let meta = fs::symlink_metadata(BOOT.state_dir.join(".dds")).await?;
-		let modified = meta.modified()?.duration_since(UNIX_EPOCH)?.as_micros();
+		let cha = Local::regular(&BOOT.state_dir.join(".dds")).symlink_metadata().await?;
+		let modified = cha.mtime_dur()?.as_micros();
 		Ok(modified >= self.last.load(Ordering::Relaxed) as u128)
 	}
 }
