@@ -3,7 +3,7 @@ use std::ffi::{c_char, c_void};
 use core_foundation_sys::{array::CFArrayRef, base::CFAllocatorRef, dictionary::CFDictionaryRef, runloop::CFRunLoopRef, string::CFStringRef};
 
 #[link(name = "DiskArbitration", kind = "framework")]
-extern "C" {
+unsafe extern "C" {
 	pub fn DASessionCreate(allocator: CFAllocatorRef) -> *const c_void;
 
 	pub fn DADiskCreateFromBSDName(
@@ -16,14 +16,14 @@ extern "C" {
 
 	pub fn DARegisterDiskAppearedCallback(
 		session: *const c_void,
-		match_: CFDictionaryRef,
+		r#match: CFDictionaryRef,
 		callback: extern "C" fn(disk: *const c_void, context: *mut c_void),
 		context: *mut c_void,
 	);
 
 	pub fn DARegisterDiskDescriptionChangedCallback(
 		session: *const c_void,
-		match_: CFDictionaryRef,
+		r#match: CFDictionaryRef,
 		watch: CFArrayRef,
 		callback: extern "C" fn(disk: *const c_void, keys: CFArrayRef, context: *mut c_void),
 		context: *mut c_void,
@@ -31,7 +31,7 @@ extern "C" {
 
 	pub fn DARegisterDiskDisappearedCallback(
 		session: *const c_void,
-		match_: CFDictionaryRef,
+		r#match: CFDictionaryRef,
 		callback: extern "C" fn(disk: *const c_void, context: *mut c_void),
 		context: *mut c_void,
 	);
