@@ -1,30 +1,26 @@
-use crossterm::event::{MouseEvent, MouseEventKind};
+use anyhow::Result;
+use crossterm::event::MouseEventKind;
 use mlua::{ObjectLike, Table};
 use tracing::error;
+use yazi_actor::lives::Lives;
 use yazi_config::YAZI;
+use yazi_macro::succ;
+use yazi_parser::app::MouseOpt;
 use yazi_plugin::LUA;
+use yazi_shared::data::Data;
 
-use crate::{app::App, lives::Lives};
-
-struct Opt {
-	event: MouseEvent,
-}
-
-impl From<MouseEvent> for Opt {
-	fn from(event: MouseEvent) -> Self { Self { event } }
-}
+use crate::app::App;
 
 impl App {
-	#[yazi_codegen::command]
-	pub fn mouse(&mut self, opt: Opt) {
+	pub fn mouse(&mut self, opt: MouseOpt) -> Result<Data> {
 		let event = yazi_plugin::bindings::MouseEvent::from(opt.event);
-		let Some(size) = self.term.as_ref().and_then(|t| t.size().ok()) else { return };
+		let Some(size) = self.term.as_ref().and_then(|t| t.size().ok()) else { succ!() };
 
-		let res = Lives::scope(&self.cx, move || {
-			let area = yazi_plugin::elements::Rect::from(size);
+		let result = Lives::scope(&self.core, move || {
+			let area = yazi_binding::elements::Rect::from(size);
 			let root = LUA.globals().raw_get::<Table>("Root")?.call_method::<Table>("new", area)?;
 
-			if matches!(event.kind, MouseEventKind::Down(_) if YAZI.mgr.mouse_events.draggable()) {
+			if matches!(event.kind, MouseEventKind::Down(_) if YAZI.mgr.mouse_events.get().draggable()) {
 				root.raw_set("_drag_start", event)?;
 			}
 
@@ -45,8 +41,9 @@ impl App {
 			Ok(())
 		});
 
-		if let Err(e) = res {
+		if let Err(ref e) = result {
 			error!("{e}");
 		}
+		succ!(result?);
 	}
 }
