@@ -1,15 +1,13 @@
-use std::ffi::OsString;
-
-use tokio::fs;
 use yazi_boot::ARGS;
-use yazi_shared::event::EventQuit;
+use yazi_fs::provider::{Provider, local::Local};
+use yazi_shared::{event::EventQuit, strand::{StrandBuf, StrandLike, ToStrand}};
 
 use crate::{Term, app::App};
 
 impl App {
 	pub(crate) fn quit(&mut self, opt: EventQuit) -> ! {
-		self.cx.tasks.shutdown();
-		self.cx.mgr.shutdown();
+		self.core.tasks.shutdown();
+		self.core.mgr.shutdown();
 
 		futures::executor::block_on(async {
 			_ = futures::join!(
@@ -25,14 +23,14 @@ impl App {
 
 	async fn cwd_to_file(&self, no: bool) {
 		if let Some(p) = ARGS.cwd_file.as_ref().filter(|_| !no) {
-			let cwd = self.cx.mgr.cwd().as_os_str();
-			fs::write(p, cwd.as_encoded_bytes()).await.ok();
+			let cwd = self.core.mgr.cwd().to_strand();
+			Local::regular(p).write(cwd.encoded_bytes()).await.ok();
 		}
 	}
 
-	async fn selected_to_file(&self, selected: Option<OsString>) {
+	async fn selected_to_file(&self, selected: Option<StrandBuf>) {
 		if let (Some(s), Some(p)) = (selected, &ARGS.chooser_file) {
-			fs::write(p, s.as_encoded_bytes()).await.ok();
+			Local::regular(p).write(s.encoded_bytes()).await.ok();
 		}
 	}
 }
