@@ -1,23 +1,23 @@
-use std::path::{MAIN_SEPARATOR_STR, Path};
+use std::path::MAIN_SEPARATOR_STR;
 
 use ratatui::{buffer::Buffer, layout::Rect, widgets::{Block, BorderType, List, ListItem, Widget}};
 use yazi_adapter::Dimension;
 use yazi_config::{THEME, popup::{Offset, Position}};
-
-use crate::Ctx;
+use yazi_core::Core;
+use yazi_shared::strand::StrandLike;
 
 pub(crate) struct Cmp<'a> {
-	cx: &'a Ctx,
+	core: &'a Core,
 }
 
 impl<'a> Cmp<'a> {
-	pub(crate) fn new(cx: &'a Ctx) -> Self { Self { cx } }
+	pub(crate) fn new(core: &'a Core) -> Self { Self { core } }
 }
 
 impl Widget for Cmp<'_> {
 	fn render(self, rect: Rect, buf: &mut Buffer) {
 		let items: Vec<_> = self
-			.cx
+			.core
 			.cmp
 			.window()
 			.iter()
@@ -26,9 +26,8 @@ impl Widget for Cmp<'_> {
 				let icon = if x.is_dir { &THEME.cmp.icon_folder } else { &THEME.cmp.icon_file };
 				let slash = if x.is_dir { MAIN_SEPARATOR_STR } else { "" };
 
-				// FIXME: Bump Rust to 1.87.0 and use `OsStr::display()` instead
-				let mut item = ListItem::new(format!(" {icon} {}{slash}", Path::new(&x.name).display()));
-				if i == self.cx.cmp.rel_cursor() {
+				let mut item = ListItem::new(format!(" {icon} {}{slash}", x.name.display()));
+				if i == self.core.cmp.rel_cursor() {
 					item = item.style(THEME.cmp.active);
 				} else {
 					item = item.style(THEME.cmp.inactive);
@@ -38,7 +37,7 @@ impl Widget for Cmp<'_> {
 			})
 			.collect();
 
-		let input_area = self.cx.mgr.area(self.cx.input.position);
+		let input_area = self.core.mgr.area(self.core.input.position);
 		let mut area = Position::sticky(Dimension::available().into(), input_area, Offset {
 			x:      1,
 			y:      0,
@@ -53,7 +52,7 @@ impl Widget for Cmp<'_> {
 			area.height = rect.height.saturating_sub(area.y).min(area.height);
 		}
 
-		yazi_plugin::elements::Clear::default().render(area, buf);
+		yazi_binding::elements::Clear::default().render(area, buf);
 		List::new(items)
 			.block(Block::bordered().border_type(BorderType::Rounded).border_style(THEME.cmp.border))
 			.render(area, buf);
