@@ -1,15 +1,15 @@
 use ratatui::{buffer::Buffer, layout::{self, Constraint, Rect}, text::Line, widgets::Widget};
 use yazi_config::{KEYMAP, THEME};
+use yazi_core::Core;
 
 use super::Bindings;
-use crate::Ctx;
 
 pub(crate) struct Help<'a> {
-	cx: &'a Ctx,
+	core: &'a Core,
 }
 
 impl<'a> Help<'a> {
-	pub fn new(cx: &'a Ctx) -> Self { Self { cx } }
+	pub fn new(core: &'a Core) -> Self { Self { core } }
 
 	fn tips() -> String {
 		match KEYMAP.help.iter().find(|&c| c.run.iter().any(|c| c.name == "filter")) {
@@ -21,8 +21,8 @@ impl<'a> Help<'a> {
 
 impl Widget for Help<'_> {
 	fn render(self, area: Rect, buf: &mut Buffer) {
-		let help = &self.cx.help;
-		yazi_plugin::elements::Clear::default().render(area, buf);
+		let help = &self.core.help;
+		yazi_binding::elements::Clear::default().render(area, buf);
 
 		let chunks = layout::Layout::vertical([Constraint::Fill(1), Constraint::Length(1)]).split(area);
 		Line::styled(
@@ -31,6 +31,6 @@ impl Widget for Help<'_> {
 		)
 		.render(chunks[1], buf);
 
-		Bindings::new(self.cx).render(chunks[0], buf);
+		Bindings::new(self.core).render(chunks[0], buf);
 	}
 }
