@@ -1,27 +1,27 @@
 use mlua::{ObjectLike, Table};
 use ratatui::{buffer::Buffer, layout::Rect, widgets::Widget};
 use tracing::error;
+use yazi_binding::elements::render_once;
 use yazi_config::LAYOUT;
-use yazi_plugin::{LUA, elements::render_once};
-
-use crate::Ctx;
+use yazi_core::Core;
+use yazi_plugin::LUA;
 
 pub(crate) struct Progress<'a> {
-	cx: &'a Ctx,
+	core: &'a Core,
 }
 
 impl<'a> Progress<'a> {
-	pub(crate) fn new(cx: &'a Ctx) -> Self { Self { cx } }
+	pub(crate) fn new(core: &'a Core) -> Self { Self { core } }
 }
 
 impl Widget for Progress<'_> {
 	fn render(self, _: Rect, buf: &mut Buffer) {
 		let mut f = || {
-			let area = yazi_plugin::elements::Rect::from(LAYOUT.get().progress);
+			let area = yazi_binding::elements::Rect::from(LAYOUT.get().progress);
 			let progress =
 				LUA.globals().raw_get::<Table>("Progress")?.call_method::<Table>("use", area)?;
 
-			render_once(progress.call_method("redraw", ())?, buf, |p| self.cx.mgr.area(p));
+			render_once(progress.call_method("redraw", ())?, buf, |p| self.core.mgr.area(p));
 			Ok::<_, mlua::Error>(())
 		};
 		if let Err(e) = f() {
