@@ -1,10 +1,10 @@
-use std::{collections::{HashMap, HashSet}, mem, ops::{Deref, Not}};
+use std::{mem, ops::{Deref, DerefMut, Not}};
 
-use tokio::{fs::{self, DirEntry}, select, sync::mpsc::{self, UnboundedReceiver}};
-use yazi_shared::{Id, url::{Url, Urn, UrnBuf}};
+use hashbrown::{HashMap, HashSet};
+use yazi_shared::{Id, path::{PathBufDyn, PathDyn}};
 
 use super::{FilesSorter, Filter};
-use crate::{FILES_TICKET, File, FilesOp, SortBy, cha::Cha, mounts::PARTITIONS};
+use crate::{FILES_TICKET, File, SortBy};
 
 #[derive(Default)]
 pub struct Files {
@@ -14,7 +14,7 @@ pub struct Files {
 	version:      u64,
 	pub revision: u64,
 
-	pub sizes: HashMap<UrnBuf, u64>,
+	pub sizes: HashMap<PathBufDyn, u64>,
 
 	sorter:      FilesSorter,
 	filter:      Option<Filter>,
@@ -27,73 +27,13 @@ impl Deref for Files {
 	fn deref(&self) -> &Self::Target { &self.items }
 }
 
-impl Files {
-	pub fn new(show_hidden: bool) -> Self { Self { show_hidden, ..Default::default() } }
-
-	pub async fn from_dir(dir: &Url) -> std::io::Result<UnboundedReceiver<File>> {
-		let mut it = fs::read_dir(dir).await?;
-		let (tx, rx) = mpsc::unbounded_channel();
-
-		tokio::spawn(async move {
-			while let Ok(Some(item)) = it.next_entry().await {
-				select! {
-					_ = tx.closed() => break,
-					result = item.metadata() => {
-						let url = Url::from(item.path());
-						_ = tx.send(match result {
-							Ok(meta) => File::from_follow(url, meta).await,
-							Err(_) => File::from_dummy(url, item.file_type().await.ok())
-						});
-					}
-				}
-			}
-		});
-		Ok(rx)
-	}
-
-	pub async fn from_dir_bulk(dir: &Url) -> std::io::Result<Vec<File>> {
-		let mut it = fs::read_dir(dir).await?;
-		let mut entries = Vec::with_capacity(5000);
-		while let Ok(Some(entry)) = it.next_entry().await {
-			entries.push(entry);
-		}
-
-		let (first, rest) = entries.split_at(entries.len() / 3);
-		let (second, third) = rest.split_at(entries.len() / 3);
-		async fn go(entries: &[DirEntry]) -> Vec<File> {
-			let mut files = Vec::with_capacity(entries.len());
-			for entry in entries {
-				let url = Url::from(entry.path());
-				files.push(match entry.metadata().await {
-					Ok(meta) => File::from_follow(url, meta).await,
-					Err(_) => File::from_dummy(url, entry.file_type().await.ok()),
-				});
-			}
-			files
-		}
-
-		Ok(
-			futures::future::join_all([go(first), go(second), go(third)])
-				.await
-				.into_iter()
-				.flatten()
-				.collect(),
-		)
-	}
-
-	pub async fn assert_stale(dir: &Url, cha: Cha) -> Option<Cha> {
-		use std::io::ErrorKind;
-		match Cha::from_url(dir).await {
-			Ok(c) if !c.is_dir() => FilesOp::issue_error(dir, ErrorKind::NotADirectory).await,
-			Ok(c) if c.hits(cha) && PARTITIONS.read().heuristic(cha) => {}
-			Ok(c) => return Some(c),
-			Err(e) => FilesOp::issue_error(dir, e.kind()).await,
-		}
-		None
-	}
+impl DerefMut for Files {
+	fn deref_mut(&mut self) -> &mut Self::Target { &mut self.items }
 }
 
 impl Files {
+	pub fn new(show_hidden: bool) -> Self { Self { show_hidden, ..Default::default() } }
+
 	pub fn update_full(&mut self, files: Vec<File>) {
 		self.ticket = FILES_TICKET.next();
 
@@ -129,7 +69,7 @@ impl Files {
 		}
 	}
 
-	pub fn update_size(&mut self, mut sizes: HashMap<UrnBuf, u64>) {
+	pub fn update_size(&mut self, mut sizes: HashMap<PathBufDyn, u64>) {
 		if sizes.len() <= 50 {
 			sizes.retain(|k, v| self.sizes.get(k) != Some(v));
 		}
@@ -157,9 +97,9 @@ impl Files {
 
 		macro_rules! go {
 			($dist:expr, $src:expr, $inc:literal) => {
-				let mut todo: HashMap<_, _> = $src.into_iter().map(|f| (f.urn_owned(), f)).collect();
+				let mut todo: HashMap<_, _> = $src.into_iter().map(|f| (f.urn().to_owned(), f)).collect();
 				for f in &$dist {
-					if todo.remove(f.urn()).is_some() && todo.is_empty() {
+					if todo.remove(&f.urn()).is_some() && todo.is_empty() {
 						break;
 					}
 				}
@@ -180,27 +120,25 @@ impl Files {
 	}
 
 	#[cfg(unix)]
-	pub fn update_deleting(&mut self, urns: HashSet<UrnBuf>) -> Vec<usize> {
+	pub fn update_deleting(&mut self, urns: HashSet<PathBufDyn>) -> Vec<usize> {
+		use yazi_shared::path::PathLike;
 		if urns.is_empty() {
 			return vec![];
 		}
 
 		let (mut hidden, mut items) = if let Some(filter) = &self.filter {
-			urns.into_iter().partition(|u| {
-				(!self.show_hidden && u.as_urn().is_hidden())
-					|| !u.as_urn().name().is_some_and(|s| filter.matches(s))
-			})
+			urns.into_iter().partition(|u| (!self.show_hidden && u.is_hidden()) || !filter.matches(u))
 		} else if self.show_hidden {
 			(HashSet::new(), urns)
 		} else {
-			urns.into_iter().partition(|u| u.as_urn().is_hidden())
+			urns.into_iter().partition(|u| u.is_hidden())
 		};
 
 		let mut deleted = Vec::with_capacity(items.len());
 		if !items.is_empty() {
 			let mut i = 0;
 			self.items.retain(|f| {
-				let b = items.remove(f.urn());
+				let b = items.remove(&f.urn());
 				if b {
 					deleted.push(i);
 				}
@@ -209,7 +147,7 @@ impl Files {
 			});
 		}
 		if !hidden.is_empty() {
-			self.hidden.retain(|f| !hidden.remove(f.urn()));
+			self.hidden.retain(|f| !hidden.remove(&f.urn()));
 		}
 
 		self.revision += deleted.is_empty().not() as u64;
@@ -217,12 +155,12 @@ impl Files {
 	}
 
 	#[cfg(windows)]
-	pub fn update_deleting(&mut self, mut urns: HashSet<UrnBuf>) -> Vec<usize> {
+	pub fn update_deleting(&mut self, mut urns: HashSet<PathBufDyn>) -> Vec<usize> {
 		let mut deleted = Vec::with_capacity(urns.len());
 		if !urns.is_empty() {
 			let mut i = 0;
 			self.items.retain(|f| {
-				let b = urns.remove(f.urn());
+				let b = urns.remove(&f.urn());
 				if b {
 					deleted.push(i)
 				}
@@ -231,7 +169,7 @@ impl Files {
 			});
 		}
 		if !urns.is_empty() {
-			self.hidden.retain(|f| !urns.remove(f.urn()));
+			self.hidden.retain(|f| !urns.remove(&f.urn()));
 		}
 
 		self.revision += deleted.is_empty().not() as u64;
@@ -240,8 +178,8 @@ impl Files {
 
 	pub fn update_updating(
 		&mut self,
-		files: HashMap<UrnBuf, File>,
-	) -> (HashMap<UrnBuf, File>, HashMap<UrnBuf, File>) {
+		files: HashMap<PathBufDyn, File>,
+	) -> (HashMap<PathBufDyn, File>, HashMap<PathBufDyn, File>) {
 		if files.is_empty() {
 			return Default::default();
 		}
@@ -250,7 +188,7 @@ impl Files {
 			($dist:expr, $src:expr, $inc:literal) => {
 				let mut b = true;
 				for i in 0..$dist.len() {
-					if let Some(f) = $src.remove($dist[i].urn()) {
+					if let Some(f) = $src.remove(&$dist[i].urn()) {
 						b = b && $dist[i].cha.hits(f.cha);
 						b = b && $dist[i].urn() == f.urn();
 
@@ -267,7 +205,7 @@ impl Files {
 		let (mut hidden, mut items) = if let Some(filter) = &self.filter {
 			files
 				.into_iter()
-				.partition(|(_, f)| (f.is_hidden() && !self.show_hidden) || !filter.matches(f.name()))
+				.partition(|(_, f)| (f.is_hidden() && !self.show_hidden) || !filter.matches(f.urn()))
 		} else if self.show_hidden {
 			(HashMap::new(), files)
 		} else {
@@ -283,13 +221,13 @@ impl Files {
 		(hidden, items)
 	}
 
-	pub fn update_upserting(&mut self, files: HashMap<UrnBuf, File>) {
+	pub fn update_upserting(&mut self, files: HashMap<PathBufDyn, File>) {
 		if files.is_empty() {
 			return;
 		}
 
 		self.update_deleting(
-			files.iter().filter(|&(u, f)| u != f.urn()).map(|(_, f)| f.urn_owned()).collect(),
+			files.iter().filter(|&(u, f)| u != f.urn()).map(|(_, f)| f.urn().into()).collect(),
 		);
 
 		let (hidden, items) = self.update_updating(files);
@@ -320,7 +258,7 @@ impl Files {
 		if let Some(filter) = &self.filter {
 			files
 				.into_iter()
-				.partition(|f| (f.is_hidden() && !self.show_hidden) || !filter.matches(f.name()))
+				.partition(|f| (f.is_hidden() && !self.show_hidden) || !filter.matches(f.urn()))
 		} else if self.show_hidden {
 			(vec![], files.into_iter().collect())
 		} else {
@@ -332,7 +270,7 @@ impl Files {
 impl Files {
 	// --- Items
 	#[inline]
-	pub fn position(&self, urn: &Urn) -> Option<usize> { self.iter().position(|f| urn == f.urn()) }
+	pub fn position(&self, urn: PathDyn) -> Option<usize> { self.iter().position(|f| urn == f.urn()) }
 
 	// --- Ticket
 	#[inline]
