@@ -1,8 +1,8 @@
-use std::{ffi::OsStr, fmt::Display, ops::Range};
+use std::{fmt::Display, ops::Range};
 
 use anyhow::Result;
 use regex::bytes::{Regex, RegexBuilder};
-use yazi_shared::event::Cmd;
+use yazi_shared::{event::Cmd, strand::AsStrand};
 
 pub struct Filter {
 	raw:   String,
@@ -23,11 +23,17 @@ impl Filter {
 	}
 
 	#[inline]
-	pub fn matches(&self, name: &OsStr) -> bool { self.regex.is_match(name.as_encoded_bytes()) }
+	#[allow(private_bounds)]
+	pub fn matches<T>(&self, name: T) -> bool
+	where
+		T: AsStrand,
+	{
+		self.regex.is_match(name.as_strand().encoded_bytes())
+	}
 
 	#[inline]
-	pub fn highlighted(&self, name: &OsStr) -> Option<Vec<Range<usize>>> {
-		self.regex.find(name.as_encoded_bytes()).map(|m| vec![m.range()])
+	pub fn highlighted(&self, name: impl AsStrand) -> Option<Vec<Range<usize>>> {
+		self.regex.find(name.as_strand().encoded_bytes()).map(|m| vec![m.range()])
 	}
 }
 
@@ -39,7 +45,7 @@ impl Display for Filter {
 	fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result { f.write_str(&self.raw) }
 }
 
-#[derive(Default, PartialEq, Eq)]
+#[derive(Clone, Copy, Debug, Default, Eq, PartialEq)]
 pub enum FilterCase {
 	Smart,
 	#[default]
