@@ -3,7 +3,7 @@ use std::{ffi::{CStr, CString, OsString, c_void}, mem, os::unix::{ffi::OsStringE
 use anyhow::{Result, bail};
 use core_foundation_sys::{array::CFArrayRef, base::{CFRelease, kCFAllocatorDefault}, runloop::{CFRunLoopGetCurrent, CFRunLoopRun, kCFRunLoopDefaultMode}};
 use libc::{c_char, mach_port_t};
-use objc::{msg_send, runtime::Object, sel, sel_impl};
+use objc2::{msg_send, runtime::AnyObject};
 use scopeguard::defer;
 use tracing::error;
 use yazi_ffi::{CFDict, CFString, DADiskCopyDescription, DADiskCreateFromBSDName, DARegisterDiskAppearedCallback, DARegisterDiskDescriptionChangedCallback, DARegisterDiskDisappearedCallback, DASessionCreate, DASessionScheduleWithRunLoop, IOIteratorNext, IOObjectRelease, IORegistryEntryCreateCFProperty, IOServiceGetMatchingServices, IOServiceMatching};
@@ -12,7 +12,7 @@ use yazi_shared::natsort;
 use super::{Locked, Partition, Partitions};
 
 impl Partitions {
-	pub fn monitor<F>(me: Locked, cb: F)
+	pub fn monitor<F>(me: &'static Locked, cb: F)
 	where
 		F: Fn() + Copy + Send + 'static,
 	{
@@ -39,12 +39,11 @@ impl Partitions {
 			}
 
 			let create_context = || {
-				let me = me.clone();
 				let boxed: Box<dyn Fn()> = Box::new(move || {
 					if mem::replace(&mut me.write().need_update, true) {
 						return;
 					}
-					Self::update(me.clone(), cb);
+					Self::update(me, cb);
 				});
 				Box::into_raw(Box::new(boxed)) as *mut c_void
 			};
@@ -70,7 +69,7 @@ impl Partitions {
 		});
 	}
 
-	fn update(me: Locked, cb: impl Fn() + Send + 'static) {
+	fn update(me: &'static Locked, cb: impl Fn() + Send + 'static) {
 		_ = tokio::task::spawn_blocking(move || {
 			let result = Self::all_names().and_then(Self::all_partitions);
 			if let Err(ref e) = result {
@@ -162,7 +161,7 @@ impl Partitions {
 		defer! { unsafe { CFRelease(property) } };
 
 		#[allow(unexpected_cfgs)]
-		let cstr: *const c_char = unsafe { msg_send![property as *const Object, UTF8String] };
+		let cstr: *const c_char = unsafe { msg_send![property as *const AnyObject, UTF8String] };
 		Ok(if cstr.is_null() {
 			bail!("Invalid value for the name property");
 		} else {
