@@ -29,7 +29,7 @@ function Marker:redraw()
 			w = 1,
 			h = math.min(1 + last[2] - last[1], self._area.y + self._area.h - y),
 		}
-		elements[#elements + 1] = ui.Bar(ui.Bar.LEFT):area(rect):style(last[3])
+		elements[#elements + 1] = ui.Bar(ui.Edge.LEFT):area(rect):style(last[3])
 	end
 
 	local last = { 0, 0, nil } -- start, end, style
