@@ -17,29 +17,28 @@ function Parent:redraw()
 		return {}
 	end
 
-	local items = {}
+	local left, right = {}, {}
 	for _, f in ipairs(self._folder.window) do
 		local entity = Entity:new(f)
-		items[#items + 1] = entity:redraw():truncate {
-			max = self._area.w,
-			ellipsis = entity:ellipsis(self._area.w),
-		}
+		left[#left + 1], right[#right + 1] = entity:redraw(), Linemode:new(f):redraw()
+
+		local max = math.max(0, self._area.w - right[#right]:width())
+		left[#left]:truncate { max = max, ellipsis = entity:ellipsis(max) }
 	end
 
-	return ui.List(items):area(self._area)
+	return {
+		ui.List(left):area(self._area),
+		ui.Text(right):area(self._area):align(ui.Align.RIGHT),
+	}
 end
 
 -- Mouse events
 function Parent:click(event, up)
-	if up or not event.is_left then
-		return
-	end
-
 	local y = event.y - self._area.y + 1
 	local window = self._folder and self._folder.window or {}
 	if window[y] then
-		ya.emit("reveal", { window[y].url })
-	else
+		Entity:new(window[y]):click(event, up)
+	elseif not up and event.is_left then
 		ya.emit("leave", {})
 	end
 end
