@@ -27,9 +27,9 @@ function M:entry(job)
 		end
 
 		local value, event = ya.input {
+			pos = { "top-center", y = 2, w = 50 },
 			title = string.format('Password for "%s":', from.name),
 			obscure = true,
-			position = { "center", w = 50 },
 		}
 		if event == 1 then
 			pwd = value
@@ -53,7 +53,7 @@ function M:try_with(from, pwd, to)
 	local archive = require("archive")
 	local child, err = archive.spawn_7z { "x", "-aou", "-sccUTF-8", "-p" .. pwd, "-o" .. tostring(tmp), tostring(from) }
 	if not child then
-		fail("Failed to start both `7zz` and `7z`, error: " .. err)
+		fail("Failed to start either `7zz` or `7z`, error: " .. err)
 	end
 
 	local output, err = child:wait_with_output()
@@ -66,7 +66,7 @@ function M:try_with(from, pwd, to)
 	if not output then
 		fail("7zip failed to output when extracting '%s', error: %s", from, err)
 	elseif output.status.code ~= 0 then
-		fail("7zip exited when extracting '%s', error code %s", from, output.status.code)
+		fail("7zip exited with error code %s when extracting '%s':\n%s", output.status.code, from, output.stderr)
 	end
 end
 
