@@ -2,7 +2,8 @@ local M = {}
 
 function M:peek(job)
 	local cmd = os.getenv("YAZI_FILE_ONE") or "file"
-	local output, err = Command(cmd):arg({ "-bL", "--", tostring(job.file.url) }):stdout(Command.PIPED):output()
+	local path = tostring(job.file.cache or job.file.url)
+	local output, err = Command(cmd):arg({ "-bL", "--", path }):output()
 
 	local text
 	if output then
@@ -30,31 +31,34 @@ function M:spot(job)
 end
 
 function M:spot_base(job)
-	local url, cha = job.file.url, job.file.cha
-	local spotter = rt.plugin.spotter(url, job.mime)
-	local previewer = rt.plugin.previewer(url, job.mime)
+	local cha = job.file.cha
+	local spotter = rt.plugin.spotter(job.file, job.mime)
+	local previewer = rt.plugin.previewer(job.file, job.mime)
 	local fetchers = rt.plugin.fetchers(job.file, job.mime)
-	local preloaders = rt.plugin.preloaders(url, job.mime)
+	local preloaders = rt.plugin.preloaders(job.file, job.mime)
 
 	for i, v in ipairs(fetchers) do
 		fetchers[i] = v.cmd
 	end
+	fetchers = #fetchers ~= 0 and fetchers or { "-" }
+
 	for i, v in ipairs(preloaders) do
 		preloaders[i] = v.cmd
 	end
+	preloaders = #preloaders ~= 0 and preloaders or { "-" }
 
 	return {
 		ui.Row({ "Base" }):style(ui.Style():fg("green")),
-		ui.Row { "  Created:", cha.btime and os.date("%y/%m/%d %H:%M", math.floor(cha.btime)) or "-" },
-		ui.Row { "  Modified:", cha.mtime and os.date("%y/%m/%d %H:%M", math.floor(cha.mtime)) or "-" },
+		ui.Row { "  Created:", cha.btime and os.date("%Y-%m-%d %H:%M:%S", math.floor(cha.btime)) or "-" },
+		ui.Row { "  Modified:", cha.mtime and os.date("%Y-%m-%d %H:%M:%S", math.floor(cha.mtime)) or "-" },
 		ui.Row { "  Mimetype:", job.mime },
 		ui.Row {},
 
 		ui.Row({ "Plugins" }):style(ui.Style():fg("green")),
 		ui.Row { "  Spotter:", spotter and spotter.cmd or "-" },
 		ui.Row { "  Previewer:", previewer and previewer.cmd or "-" },
-		ui.Row { "  Fetchers:", #fetchers ~= 0 and fetchers or "-" },
-		ui.Row { "  Preloaders:", #preloaders ~= 0 and preloaders or "-" },
+		ui.Row({ "  Fetchers:", fetchers }):height(#fetchers),
+		ui.Row({ "  Preloaders:", preloaders }):height(#preloaders),
 	}
 end
 
