@@ -11,9 +11,12 @@ end)
 function M:entry()
 	ya.emit("escape", { visual = true })
 
-	local _permit = ya.hide()
 	local cwd, selected = state()
+	if cwd.scheme.is_virtual then
+		return ya.notify { title = "Fzf", content = "Not supported under virtual filesystems", timeout = 5, level = "warn" }
+	end
 
+	local _permit = ui.hide()
 	local output, err = M.run_with(cwd, selected)
 	if not output then
 		return ya.notify { title = "Fzf", content = tostring(err), timeout = 5, level = "error" }
@@ -22,7 +25,7 @@ function M:entry()
 	local urls = M.split_urls(cwd, output)
 	if #urls == 1 then
 		local cha = #selected == 0 and fs.cha(urls[1])
-		ya.emit(cha and cha.is_dir and "cd" or "reveal", { urls[1] })
+		ya.emit(cha and cha.is_dir and "cd" or "reveal", { urls[1], raw = true })
 	elseif #urls > 1 then
 		urls.state = #selected > 0 and "off" or "on"
 		ya.emit("toggle_all", urls)
