@@ -6,15 +6,17 @@ function M:peek(job)
 		return
 	end
 
-	local ok, err = self:preload(job)
-	if not ok or err then
-		return
+	local ok, err, bound = self:preload(job)
+	if bound and bound > 0 then
+		return ya.emit("peek", { bound - 1, only_if = job.file.url, upper_bound = true })
+	elseif not ok or err then
+		return ya.preview_widget(job, err)
 	end
 
 	ya.sleep(math.max(0, rt.preview.image_delay / 1000 + start - os.clock()))
 
 	local _, err = ya.image_show(cache, job.area)
-	ya.preview_widget(job, err and ui.Text(tostring(err)):area(job.area):wrap(ui.Wrap.YES))
+	ya.preview_widget(job, err)
 end
 
 function M:seek(job)
@@ -38,29 +40,18 @@ function M:preload(job)
 			"-l", job.skip + 1,
 			"-singlefile",
 			"-jpeg", "-jpegopt", "quality=" .. rt.preview.image_quality,
-			"-scale-to-x", rt.preview.max_width, "-scale-to-y", "-1",
-			tostring(job.file.url),
-			tostring(cache),
+			tostring(job.file.url), tostring(cache),
 		})
-		:stderr(Command.PIPED)
 		:output()
 
 	if not output then
 		return true, Err("Failed to start `pdftoppm`, error: %s", err)
 	elseif not output.status.success then
-		local pages = tonumber(output.stderr:match("the last page %((%d+)%)")) or 0
-		if job.skip > 0 and pages > 0 then
-			ya.emit("peek", { math.max(0, pages - 1), only_if = job.file.url, upper_bound = true })
-		end
-		return true, Err("Failed to convert PDF to image, stderr: %s", output.stderr)
+		local pages = job.skip > 0 and tonumber(output.stderr:match("the last page %((%d+)%)"))
+		return true, Err("Failed to convert PDF to image, stderr: %s", output.stderr), pages
 	end
 
-	local ok, err = os.rename(string.format("%s.jpg", cache), tostring(cache))
-	if ok then
-		return true
-	else
-		return false, Err("Failed to rename `%s.jpg` to `%s`, error: %s", cache, cache, err)
-	end
+	return ya.image_precache(Url(cache .. ".jpg"), cache)
 end
 
 return M
