@@ -8,13 +8,13 @@ function M:peek(job)
 
 	local ok, err = self:preload(job)
 	if not ok or err then
-		return
+		return ya.preview_widget(job, err)
 	end
 
 	ya.sleep(math.max(0, rt.preview.image_delay / 1000 + start - os.clock()))
 
 	local _, err = ya.image_show(cache, job.area)
-	ya.preview_widget(job, err and ui.Text(tostring(err)):area(job.area):wrap(ui.Wrap.YES))
+	ya.preview_widget(job, err)
 end
 
 function M:seek() end
@@ -29,19 +29,25 @@ function M:preload(job)
 	local cmd = Command("resvg"):arg {
 		"-w", rt.preview.max_width, "-h", rt.preview.max_height,
 		"--image-rendering", "optimizeSpeed",
-		tostring(job.file.url), tostring(cache)
 	}
+	if job.args.bg then
+		cmd = cmd:arg { "--background", job.args.bg }
+	end
 	if rt.tasks.image_alloc > 0 then
 		cmd = cmd:memory(rt.tasks.image_alloc)
 	end
 
-	local child, err = cmd:spawn()
+	local child, err = cmd:arg({ tostring(job.file.url), tostring(cache) }):spawn()
 	if not child then
 		return true, Err("Failed to start `resvg`, error: %s", err)
 	end
 
 	local status, err
-	while true do
+	if rt.tasks.image_alloc == 0 then
+		status, err = child:wait()
+	end
+
+	while not status and not err do
 		ya.sleep(0.2)
 
 		status, err = child:try_wait()
@@ -56,14 +62,15 @@ function M:preload(job)
 		if mem and mem > rt.tasks.image_alloc then
 			child:start_kill()
 			err = Err("memory limit exceeded, pid: %s, memory: %s", id, mem)
-			break
 		end
 	end
 
-	if status then
-		return status.success
-	else
+	if not status then
 		return true, Err("Error while running `resvg`: %s", err)
+	elseif not status.success then
+		return false, Err("`resvg` exited with error code: %s", status.code)
+	else
+		return true
 	end
 end
 
