@@ -8,13 +8,13 @@ function M:peek(job)
 
 	local ok, err = self:preload(job)
 	if not ok or err then
-		return
+		return ya.preview_widget(job, err)
 	end
 
 	ya.sleep(math.max(0, rt.preview.image_delay / 1000 + start - os.clock()))
 
 	local _, err = ya.image_show(cache, job.area)
-	ya.preview_widget(job, err and ui.Text(tostring(err)):area(job.area):wrap(ui.Wrap.YES))
+	ya.preview_widget(job, err)
 end
 
 function M:seek(job)
@@ -52,34 +52,35 @@ function M:preload(job)
 		return false
 	end
 
-	-- stylua: ignore
-	local cmd = Command("ffmpeg"):arg({
-		"-v", "quiet", "-threads", 1, "-hwaccel", "auto",
-		"-skip_frame", "nokey",
-		"-an", "-sn", "-dn",
-	})
+	local cmd = Command("ffmpeg")
+		:stderr(Command.PIPED)
+		:arg { "-v", "warning", "-hwaccel", "auto", "-threads", 1, "-an", "-sn", "-dn" }
 
 	if percent ~= 0 then
 		cmd:arg { "-ss", math.floor(meta.format.duration * percent / 100) }
 	end
-	cmd:arg { "-i", tostring(job.file.url) }
+	cmd:arg { "-skip_frame", "nokey", "-i", tostring(job.file.url) }
 	if percent == 0 then
 		cmd:arg { "-map", "disp:attached_pic" }
 	end
 
 	-- stylua: ignore
-	local status, err = cmd:arg({
+	local output, err = cmd:arg({
 		"-vframes", 1,
 		"-q:v", 31 - math.floor(rt.preview.image_quality * 0.3),
 		"-vf", string.format("scale='min(%d,iw)':'min(%d,ih)':force_original_aspect_ratio=decrease:flags=fast_bilinear", rt.preview.max_width, rt.preview.max_height),
 		"-f", "image2",
 		"-y", tostring(cache),
-	}):status()
+	}):output()
 
-	if status then
-		return status.success
-	else
+	if not output then
 		return true, Err("Failed to start `ffmpeg`, error: %s", err)
+	elseif output.status.success then
+		return true
+	elseif output.stderr:find("No filtered frames for output stream", 1, true) then
+		return true, Err("No more keyframes available")
+	else
+		return false, Err("`ffmpeg` exited with error code %s: %s", output.status.code, output.stderr)
 	end
 end
 
