@@ -2,11 +2,12 @@ use std::process::Stdio;
 
 use anyhow::Result;
 use tokio::{io::{AsyncBufReadExt, BufReader}, process::Command, sync::mpsc::{self, UnboundedReceiver}};
-use yazi_fs::File;
-use yazi_shared::url::Url;
+use yazi_fs::{File, FsUrl};
+use yazi_shared::url::{AsUrl, UrlBuf, UrlLike};
+use yazi_vfs::VfsFile;
 
 pub struct RgOpt {
-	pub cwd:     Url,
+	pub cwd:     UrlBuf,
 	pub hidden:  bool,
 	pub subject: String,
 	pub args:    Vec<String>,
@@ -18,7 +19,7 @@ pub fn rg(opt: RgOpt) -> Result<UnboundedReceiver<File>> {
 		.arg(if opt.hidden { "--hidden" } else { "--no-hidden" })
 		.args(opt.args)
 		.arg(opt.subject)
-		.arg(&opt.cwd)
+		.arg(&*opt.cwd.as_url().unified_path())
 		.kill_on_drop(true)
 		.stdout(Stdio::piped())
 		.stderr(Stdio::null())
@@ -29,7 +30,10 @@ pub fn rg(opt: RgOpt) -> Result<UnboundedReceiver<File>> {
 
 	tokio::spawn(async move {
 		while let Ok(Some(line)) = it.next_line().await {
-			if let Ok(file) = File::new(opt.cwd.join(line)).await {
+			let Ok(url) = opt.cwd.try_join(line) else {
+				continue;
+			};
+			if let Ok(file) = File::new(url).await {
 				tx.send(file).ok();
 			}
 		}
