@@ -1,11 +1,11 @@
 use anyhow::{Context, Result};
+use futures::executor::block_on;
 use mlua::Lua;
+use yazi_binding::{Runtime, runtime_mut};
 use yazi_boot::BOOT;
 use yazi_macro::plugin_preset as preset;
 use yazi_shared::RoCell;
 
-use crate::runtime::Runtime;
-
 pub static LUA: RoCell<Lua> = RoCell::new();
 
 pub(super) fn init_lua() -> Result<()> {
@@ -17,21 +17,22 @@ pub(super) fn init_lua() -> Result<()> {
 }
 
 fn stage_1(lua: &'static Lua) -> Result<()> {
-	lua.set_named_registry_value("ir", Runtime::default())?;
+	lua.set_app_data(Runtime::new());
 
 	// Base
 	let globals = lua.globals();
-	globals.raw_set("ui", crate::elements::compose(lua)?)?;
-	globals.raw_set("ya", crate::utils::compose(lua, false)?)?;
-	globals.raw_set("fs", crate::fs::compose(lua)?)?;
-	globals.raw_set("ps", crate::pubsub::compose(lua)?)?;
-	globals.raw_set("rt", crate::config::Runtime::compose(lua)?)?;
-	globals.raw_set("th", crate::config::Theme::compose(lua)?)?;
+	globals.raw_set("ui", crate::elements::compose())?;
+	globals.raw_set("ya", crate::utils::compose(false))?;
+	globals.raw_set("fs", crate::fs::compose())?;
+	globals.raw_set("ps", crate::pubsub::compose())?;
+	globals.raw_set("rt", crate::runtime::compose())?;
+	globals.raw_set("th", crate::theme::compose())?;
 
 	yazi_binding::Error::install(lua)?;
-	crate::bindings::Cha::install(lua)?;
+	yazi_binding::Cha::install(lua)?;
 	crate::loader::install(lua)?;
-	crate::file::File::install(lua)?;
+	crate::process::install(lua)?;
+	yazi_binding::File::install(lua)?;
 	yazi_binding::Url::install(lua)?;
 
 	// Addons
@@ -53,6 +54,7 @@ fn stage_1(lua: &'static Lua) -> Result<()> {
 	lua.load(preset!("components/status")).set_name("status.lua").exec()?;
 	lua.load(preset!("components/tab")).set_name("tab.lua").exec()?;
 	lua.load(preset!("components/tabs")).set_name("tabs.lua").exec()?;
+	lua.load(preset!("components/tasks")).set_name("tasks.lua").exec()?;
 
 	Ok(())
 }
@@ -62,8 +64,9 @@ fn stage_2(lua: &'static Lua) -> mlua::Result<()> {
 	lua.load(preset!("compat")).set_name("compat.lua").exec()?;
 
 	if let Ok(b) = std::fs::read(BOOT.config_dir.join("init.lua")) {
-		lua.load(b).set_name("init.lua").exec()?;
+		block_on(lua.load(b).set_name("init.lua").exec_async())?;
 	}
 
+	runtime_mut!(lua)?.initing = false;
 	Ok(())
 }
