@@ -1,8 +1,7 @@
 use mlua::{Function, IntoLuaMulti, Lua, LuaSerdeExt, Value};
-use yazi_binding::Error;
+use yazi_binding::{Error, SER_OPT};
 
 use super::Utils;
-use crate::config::OPTS;
 
 impl Utils {
 	pub(super) fn json_encode(lua: &Lua) -> mlua::Result<Function> {
@@ -17,7 +16,7 @@ impl Utils {
 	pub(super) fn json_decode(lua: &Lua) -> mlua::Result<Function> {
 		lua.create_async_function(|lua, s: mlua::String| async move {
 			match serde_json::from_slice::<serde_json::Value>(&s.as_bytes()) {
-				Ok(v) => lua.to_value_with(&v, OPTS)?.into_lua_multi(&lua),
+				Ok(v) => lua.to_value_with(&v, SER_OPT)?.into_lua_multi(&lua),
 				Err(e) => (Value::Nil, Error::Serde(e)).into_lua_multi(&lua),
 			}
 		})
