@@ -1,38 +1,13 @@
 use mlua::{AnyUserData, ExternalError, Function, IntoLuaMulti, Lua, Table, Value};
+use yazi_binding::{Error, elements::{Area, Renderable, Text}};
 use yazi_config::YAZI;
-use yazi_macro::emit;
-use yazi_shared::{errors::PeekError, event::Cmd};
+use yazi_fs::FsUrl;
+use yazi_parser::mgr::{PreviewLock, UpdatePeekedOpt};
+use yazi_proxy::MgrProxy;
+use yazi_shared::{errors::PeekError, url::AsUrl};
 
 use super::Utils;
-use crate::{elements::{Area, Rect, Renderable, Text}, external::Highlighter, file::FileRef};
-
-#[derive(Debug, Default)]
-pub struct PreviewLock {
-	pub url:  yazi_shared::url::Url,
-	pub cha:  yazi_fs::cha::Cha,
-	pub mime: String,
-
-	pub skip: usize,
-	pub area: Rect,
-	pub data: Vec<Renderable>,
-}
-
-impl TryFrom<Table> for PreviewLock {
-	type Error = mlua::Error;
-
-	fn try_from(t: Table) -> Result<Self, Self::Error> {
-		let file: FileRef = t.raw_get("file")?;
-		Ok(Self {
-			url:  file.url_owned(),
-			cha:  file.cha,
-			mime: t.raw_get("mime")?,
-
-			skip: t.raw_get("skip")?,
-			area: t.raw_get("area")?,
-			data: Default::default(),
-		})
-	}
-}
+use crate::external::Highlighter;
 
 impl Utils {
 	pub(super) fn preview_code(lua: &Lua) -> mlua::Result<Function> {
@@ -40,7 +15,8 @@ impl Utils {
 			let area: Area = t.raw_get("area")?;
 			let mut lock = PreviewLock::try_from(t)?;
 
-			let inner = match Highlighter::new(&lock.url).highlight(lock.skip, area.size()).await {
+			let path = lock.url.as_url().unified_path();
+			let inner = match Highlighter::new(path).highlight(lock.skip, area.size()).await {
 				Ok(text) => text,
 				Err(e @ PeekError::Exceed(max)) => return (e.to_string(), max).into_lua_multi(&lua),
 				Err(e @ PeekError::Unexpected(_)) => {
@@ -55,7 +31,7 @@ impl Utils {
 				scroll: Default::default(),
 			})];
 
-			emit!(Call(Cmd::new("mgr:update_peeked").with_any("lock", lock)));
+			MgrProxy::update_peeked(UpdatePeekedOpt { lock });
 			().into_lua_multi(&lua)
 		})
 	}
@@ -69,11 +45,23 @@ impl Utils {
 					.sequence_values::<AnyUserData>()
 					.map(|ud| ud.and_then(Renderable::try_from))
 					.collect::<mlua::Result<_>>()?,
-				Value::UserData(ud) => vec![Renderable::try_from(ud)?],
+				Value::UserData(ud) => match Renderable::try_from(&ud) {
+					Ok(r) => vec![r],
+					Err(e) => {
+						if let Ok(err) = ud.take::<Error>() {
+							vec![
+								Renderable::Clear(yazi_binding::elements::Clear { area: lock.area.into() }),
+								Renderable::from(err).with_area(lock.area),
+							]
+						} else {
+							Err(e)?
+						}
+					}
+				},
 				_ => Err("preview widget must be a renderable element or a table of them".into_lua_err())?,
 			};
 
-			emit!(Call(Cmd::new("mgr:update_peeked").with_any("lock", lock)));
+			MgrProxy::update_peeked(UpdatePeekedOpt { lock });
 			Ok(())
 		})
 	}
