@@ -1,14 +1,16 @@
 use mlua::{IntoLua, Lua, Value};
-
-use crate::Composer;
+use yazi_binding::{Composer, ComposerSet};
 
 pub(super) struct Utils;
 
-pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
-	Composer::make(lua, 45, move |lua, key| {
+pub fn compose(
+	isolate: bool,
+) -> Composer<impl Fn(&Lua, &[u8]) -> mlua::Result<Value>, ComposerSet> {
+	fn get(lua: &Lua, key: &[u8], isolate: bool) -> mlua::Result<Value> {
 		match key {
 			// App
 			b"id" => Utils::id(lua)?,
+			b"drop" => Utils::drop(lua)?,
 			b"hide" => Utils::hide(lua)?,
 
 			// Cache
@@ -17,10 +19,7 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 			// Call
 			b"render" => Utils::render(lua)?,
 			b"emit" => Utils::emit(lua)?,
-			b"app_emit" => Utils::app_emit(lua)?,
 			b"mgr_emit" => Utils::mgr_emit(lua)?,
-			b"manager_emit" => Utils::mgr_emit(lua)?, // TODO: remove this in the future
-			b"input_emit" => Utils::input_emit(lua)?,
 
 			// Image
 			b"image_info" => Utils::image_info(lua)?,
@@ -44,7 +43,6 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 			// Preview
 			b"preview_code" => Utils::preview_code(lua)?,
 			b"preview_widget" => Utils::preview_widget(lua)?,
-			b"preview_widgets" => Utils::preview_widget(lua)?, // TODO: remove this in the future
 
 			// Process
 			b"proc_info" => Utils::proc_info(lua)?,
@@ -55,6 +53,7 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 
 			// Sync
 			b"sync" => Utils::sync(lua, isolate)?,
+			b"async" => Utils::r#async(lua, isolate)?,
 			b"chan" => Utils::chan(lua)?,
 			b"join" => Utils::join(lua)?,
 			b"select" => Utils::select(lua)?,
@@ -88,5 +87,9 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 			_ => return Ok(Value::Nil),
 		}
 		.into_lua(lua)
-	})
+	}
+
+	fn set(_: &Lua, _: &[u8], value: Value) -> mlua::Result<Value> { Ok(value) }
+
+	Composer::new(move |lua, key| get(lua, key, isolate), set)
 }
