@@ -1,3 +1,5 @@
+use serde::Serialize;
+
 #[derive(Clone, Copy, Debug)]
 pub enum Either<L, R> {
 	Left(L),
@@ -7,28 +9,28 @@ pub enum Either<L, R> {
 impl<L, R> Either<L, R> {
 	pub fn left(&self) -> Option<&L> {
 		match self {
-			Either::Left(l) => Some(l),
+			Self::Left(l) => Some(l),
 			_ => None,
 		}
 	}
 
 	pub fn right(&self) -> Option<&R> {
 		match self {
-			Either::Right(r) => Some(r),
+			Self::Right(r) => Some(r),
 			_ => None,
 		}
 	}
 
 	pub fn left_mut(&mut self) -> Option<&mut L> {
 		match self {
-			Either::Left(l) => Some(l),
+			Self::Left(l) => Some(l),
 			_ => None,
 		}
 	}
 
 	pub fn right_mut(&mut self) -> Option<&mut R> {
 		match self {
-			Either::Right(r) => Some(r),
+			Self::Right(r) => Some(r),
 			_ => None,
 		}
 	}
@@ -43,15 +45,45 @@ impl<L, R> Either<L, R> {
 
 	pub fn into_left(self) -> Option<L> {
 		match self {
-			Either::Left(l) => Some(l),
+			Self::Left(l) => Some(l),
 			_ => None,
 		}
 	}
 
 	pub fn into_right(self) -> Option<R> {
 		match self {
-			Either::Right(r) => Some(r),
+			Self::Right(r) => Some(r),
 			_ => None,
 		}
 	}
+
+	pub fn left_or_err<E, F: FnOnce() -> E>(self, f: F) -> Result<L, E> {
+		match self {
+			Self::Left(l) => Ok(l),
+			_ => Err(f()),
+		}
+	}
+
+	pub fn right_or_err<E, F: FnOnce() -> E>(self, f: F) -> Result<R, E> {
+		match self {
+			Self::Right(r) => Ok(r),
+			_ => Err(f()),
+		}
+	}
+}
+
+impl<L, R> Serialize for Either<L, R>
+where
+	L: Serialize,
+	R: Serialize,
+{
+	fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+	where
+		S: serde::Serializer,
+	{
+		match self {
+			Self::Left(l) => l.serialize(serializer),
+			Self::Right(r) => r.serialize(serializer),
+		}
+	}
 }
