@@ -1,19 +1,20 @@
 use std::{fmt::Display, str::FromStr};
 
-use anyhow::bail;
+use serde::Deserialize;
 
-#[derive(Debug, Default, PartialEq, Eq, Hash, Clone, Copy)]
+#[derive(Debug, Default, PartialEq, Eq, Hash, Clone, Copy, Deserialize)]
+#[serde(rename_all = "kebab-case")]
 pub enum Layer {
 	#[default]
 	App,
-	Manager,
+	Mgr,
 	Tasks,
 	Spot,
 	Pick,
 	Input,
 	Confirm,
 	Help,
-	Completion,
+	Cmp,
 	Which,
 }
 
@@ -21,35 +22,23 @@ impl Display for Layer {
 	fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
 		f.write_str(match self {
 			Self::App => "app",
-			Self::Manager => "manager",
+			Self::Mgr => "mgr",
 			Self::Tasks => "tasks",
 			Self::Spot => "spot",
 			Self::Pick => "pick",
 			Self::Input => "input",
 			Self::Confirm => "confirm",
 			Self::Help => "help",
-			Self::Completion => "completion",
+			Self::Cmp => "cmp",
 			Self::Which => "which",
 		})
 	}
 }
 
 impl FromStr for Layer {
-	type Err = anyhow::Error;
+	type Err = serde::de::value::Error;
 
 	fn from_str(s: &str) -> Result<Self, Self::Err> {
-		Ok(match s {
-			"app" => Self::App,
-			"manager" => Self::Manager,
-			"tasks" => Self::Tasks,
-			"spot" => Self::Spot,
-			"pick" => Self::Pick,
-			"input" => Self::Input,
-			"confirm" => Self::Confirm,
-			"help" => Self::Help,
-			"completion" => Self::Completion,
-			"which" => Self::Which,
-			_ => bail!("invalid layer: {s}"),
-		})
+		Self::deserialize(serde::de::value::StrDeserializer::new(s))
 	}
 }
