@@ -2,9 +2,9 @@ use std::{borrow::Cow, ops::Range};
 
 use crossterm::cursor::SetCursorStyle;
 use yazi_config::YAZI;
-use yazi_plugin::CLIPBOARD;
 
 use super::{InputSnap, InputSnaps, mode::InputMode, op::InputOp};
+use crate::CLIPBOARD;
 
 pub type InputCallback = Box<dyn Fn(&str, &str)>;
 
@@ -75,7 +75,7 @@ impl Input {
 	pub fn value(&self) -> &str { &self.snap().value }
 
 	#[inline]
-	pub fn display(&self) -> Cow<str> {
+	pub fn display(&self) -> Cow<'_, str> {
 		if self.obscure {
 			"•".repeat(self.snap().window(self.limit).len()).into()
 		} else {
